# Relocate
**Do you want to organise your files?** <br>
Then **_Relocate_** is here to help you. It will organise your files in separate folders, according to month of creation and then according to extensions.  <br><br>
Install the module from your command prompt.<br>
`pip3 install relocate`  <br>
Move to the directory where those files are located. Then open a terminal and run the following. <br>
`import relocate`  <br>
`relocate.relocateNow()`  <br><br>
Navigate to the RELOCATED folder  and you will get your files in an organised manner.  <br><br>
For any queries, contact me on LinkedIn [https://www.linkedin.com/in/sandip-palit/]